@@ -6,7 +6,7 @@
 #'
 #' For help with distance sampling and this package, there is a Google Group \url{https://groups.google.com/forum/#!forum/distance-sampling}.
 #'
-#' A example analysis is available at \url{http://distancesampling.org/R/vignettes/mexico-analysis.html}.
+#' A example analyses are available at \url{http://examples.distancesampling.org}.
 #'
 #' @name dsm-package
 #' @import mgcv nlme mrds
@@ -14,15 +14,6 @@
 NULL
 
 
-#' Offsets
-#'
-#' This will be documentation on calculating offsets.
-#'
-#' @name offsets
-#'
-NULL
-
-
 #' Data format for DSM
 #'
 #' Two \code{data.frame}s must be provided to \code{\link{dsm}}. They are referred to as \code{observation.data} and \code{segment.data}.
