@@ -41,25 +41,29 @@ test_that("formula specs",{
 
 
   ## models for density
-  D.gcv <- -2753.087937
+  D.reml <- -2812.33881
   density.D<-dsm(D~s(x,y), hn.model, segdata, obsdata,
                  weights=rep(1,nrow(segdata)))
-  expect_equal(unname(density.D$gcv.ubre), D.gcv,tolerance=par.tol, check.attributes=FALSE)
+  expect_equal(unname(density.D$gcv.ubre), D.reml,
+               tolerance=par.tol, check.attributes=FALSE)
 
   density.density<-dsm(density~s(x,y), hn.model, segdata,
                        obsdata,
                        weights=rep(1,nrow(segdata)))
-  expect_equal(unname(density.density$gcv.ubre), D.gcv,tolerance=par.tol, check.attributes=FALSE)
+  expect_equal(unname(density.density$gcv.ubre), D.reml,
+               tolerance=par.tol, check.attributes=FALSE)
 
   density.Dhat<-dsm(Dhat~s(x,y), hn.model, segdata,
                     obsdata,
                     weights=rep(1,nrow(segdata)))
-  expect_equal(unname(density.Dhat$gcv.ubre), D.gcv,tolerance=par.tol, check.attributes=FALSE)
+  expect_equal(unname(density.Dhat$gcv.ubre), D.reml,
+               tolerance=par.tol, check.attributes=FALSE)
 
   density.density.est<-dsm(density.est~s(x,y), hn.model, segdata,
                            obsdata,
                            weights=rep(1,nrow(segdata)))
-  expect_equal(unname(density.density.est$gcv.ubre), D.gcv,tolerance=par.tol, check.attributes=FALSE)
+  expect_equal(unname(density.density.est$gcv.ubre), D.reml,
+               tolerance=par.tol, check.attributes=FALSE)
 
   # check that Effort is not zero
   mex_zero_effort <- segdata
@@ -100,3 +104,19 @@ test_that("Missing columns cause errors",{
                fixed=TRUE)
 
 })
+
+test_that("Error thrown when Sample.Labels don't match up",{
+
+  seg <- segdata
+  obs <- obsdata
+
+  # now nothing will match
+  seg$Sample.Label <- paste0(seg$Sample.Label, "-wat")
+
+  expect_error(dsm(N~s(x,y), hn.model, seg, obs),
+               "No matches between segment and observation data.frame Sample.Labels!",
+               fixed=TRUE)
+
+})
+
+
